@@ -1,5 +1,6 @@
-from miniworldmaker.containers import toolbar_widgets
 from miniworldmaker.containers import toolbar
+from miniworldmaker.containers import widgets
+
 
 class ColorToolbar(toolbar.Toolbar):
     """
@@ -17,11 +18,11 @@ class ColorToolbar(toolbar.Toolbar):
 
     def get_event(self, event, data):
         if "mouse_left" in event and self.board.is_in_container(data[0], data[1]):
-            self.color_label.set_text(str(self.board.background.get_color_from_pixel(data)))
-            self.color_label.set_color(self.board.background.get_color_from_pixel(data))
+            self.color_label.set_text(str(self.board.get_color_from_pixel(data)))
+            self.color_label.set_color(self.board.get_color_from_pixel(data))
 
 
-class ColorLabel(toolbar_widgets.ToolbarLabel):
+class ColorLabel(widgets.ToolbarLabel):
     def __init__(self, text):
         super().__init__(text)
 
