@@ -1,46 +1,51 @@
 import os
 
-from miniworldmaker.board_positions import board_position, board_rect_factory, board_position_factory
+import miniworldmaker.tokens.token as token
+from miniworldmaker.board_positions import board_rect as board_rect
+from miniworldmaker.board_positions import board_position
 from miniworldmaker.containers import toolbar
-from miniworldmaker.containers.toolbar_widgets import SaveButton, LoadButton, ToolbarWidget, ToolbarLabel, ToolbarButton
-from miniworldmaker.tools.inspection_methods import InspectionMethods
-from miniworldmaker.tokens import token
-from miniworldmaker.containers.toolbar_widgets import ClearButton
+from miniworldmaker.containers import widgets
 from miniworldmaker.exceptions import miniworldmaker_exception
 
+
 class LevelDesignerToolbar(toolbar.Toolbar):
 
-    def __init__(self, board, tokens):
+    def __init__(self, board, token_classes, file):
         super().__init__()
+        self.board = board
         self.default_size = 400
         self.app = board.app
         self.selected_token_type = None
         self.dummy = None
         self.registered_events.add("all")
         self.registered_events.add("debug")
-        self.add_widget(ToolbarLabel("Left Click to add Tokens"))
-        self.add_widget(ToolbarLabel("Right Click or Wheel to change direction"))
-        self.add_widget(ToolbarLabel("SHIFT + Right Click to delete token"))
+        self.add_widget(widgets.ToolbarLabel("Left Click to add Tokens"))
+        self.add_widget(widgets.ToolbarLabel("Right Click or Wheel to change direction"))
+        self.add_widget(widgets.ToolbarLabel("SHIFT + Right Click to delete token"))
         self.prototypes = dict()
-        for cls in tokens:
-            prototype = cls((-100,-100))
+        for cls in token_classes:
+            prototype = cls((-100, -100))
             prototype.export = False
             self.prototypes[cls.__name__] = prototype
-            self.add_widget(TokenButton(cls, board, self, self.prototypes[cls.__name__]))
-        db_file = "data.db"
-        self.add_widget(SaveButton(board=self.app.board, text="Save", filename=db_file))
+            button = TokenButton(token_type=cls, board=board, parent=self, prototype=prototype)
+            self.add_widget(button, cls.__name__)
+        db_file = file
+        self.add_widget(widgets.SaveButton(board=self.board, text="Save", filename=db_file))
         if os.path.exists(db_file):
-            self.add_widget(LoadButton(board=self.app.board, text="Load", filename=db_file))
-        self.add_widget(ClearButton(board=self.app.board, text="Clear"))
+            self.add_widget(widgets.LoadButton(board=self.board, text="Load", filename=db_file))
+        self.add_widget(widgets.ClearButton(board=self.board, text="Clear"))
 
-    def _add_token_to_mouse_position(self, position,):
+    def _add_token_to_mouse_position(self, mouse_pixel_pos):
+        position = board_position.Position.from_pixel(mouse_pixel_pos)
         if self.selected_token_type:
             prototype = self.prototypes[self.selected_token_type.__name__]
-            size = prototype.size
-            rect = board_rect_factory.BoardRectFactory(self.app.board).from_position(position, size)
-            tokens = self.app.board.get_tokens_at_rect(rect)
+            rect = board_rect.Rect.from_token(prototype)
+            rect.topleft = mouse_pixel_pos
+            tokens = [token for token in self.board.tokens if token.sensing_rect(rect)]
+            # remove dummy
             if self.dummy and tokens and self.dummy in tokens:
                 tokens.remove(self.dummy)
+            # add tokens if no tokens are at current position
             if tokens:
                 print("Can't create overlapping tokens")
             else:
@@ -59,22 +64,25 @@ class LevelDesignerToolbar(toolbar.Toolbar):
         pass
 
     def handle_board_event(self, event, data):
-        # preprocess - Get BoardPosition and token at position (max: 1)
-        position = board_position_factory.BoardPositionFactory(self.app.board).from_pixel(data)
-        keys = self.app.board.app.event_manager.get_keys()
-        tokens = self.app.board.get_tokens_by_pixel(position)
+        # preprocess - Get Position and token at position (max: 1)
+        pixel_position = data
+        position = board_position.Position.from_pixel(data)
+        keys = self.board.app.event_manager.get_keys()
+        tokens = self.board.get_tokens_at_position(position)
+        # remove dummy from tokens
         if self.dummy in tokens:
             tokens.remove(self.dummy)
+        # select token at position, if there is a token
         if not tokens:
             token = None
         elif len(tokens) == 1:
             token = tokens[0]
         else:
-            raise Exception()
+            raise Exception(f"tokens is {tokens}, should be None or should have len 1")
         # Event handling
         if "mouse_left" in event:
             if not tokens and not keys:
-                self._add_token_to_mouse_position(position)
+                self._add_token_to_mouse_position(pixel_position)
             else:
                 self._select_token(token)
         elif "wheel_up" in event:
@@ -88,13 +96,10 @@ class LevelDesignerToolbar(toolbar.Toolbar):
                 self._change_direction_at_mouse_position(token, "left")
         self._update_dummy(position)
 
-
-    def _update_dummy(self, data):
-        position = board_position_factory.BoardPositionFactory(self.app.board).create(data)
+    def _update_dummy(self, position):
         if self.dummy:
             self.dummy.position = position
-            rect = board_rect_factory.BoardRectFactory(self.app.board).from_position(self.dummy.position, self.dummy.size)
-            tokens = self.app.board.get_tokens_at_rect(rect)
+            tokens = self.dummy.sensing_tokens()
             if self.dummy and tokens and self.dummy in tokens:
                 tokens.remove(self.dummy)
             if tokens:
@@ -104,24 +109,24 @@ class LevelDesignerToolbar(toolbar.Toolbar):
 
     def get_event(self, event, data):
         super().get_event(event, data)
-        if type(data) == tuple and self.app.board.is_in_container(data[0], data[1]):
+        if type(data) == tuple and self.bboard.is_in_container(data[0], data[1]):
             self.handle_board_event(event, data)
 
+
 class Dummy(token.Token):
     def on_setup(self):
-        self.add_costume((0,0,0,100))
-        self.add_costume((255,0,0,100))
+        self.add_costume((0, 0, 0, 100))
+        self.add_costume((255, 0, 0, 100))
         self.export = False
 
 
-class TokenButton(ToolbarWidget):
+class TokenButton(widgets.Widget):
 
     def __init__(self, token_type, board, parent, prototype):
-        super().__init__()
+        super().__init__("Button")
         self.parent = parent
         self.board = board
-        if prototype.costume.image_paths:
-            self._img_path = prototype.costume.image_paths[0]
+        self._img_path = prototype.costume.image_manager.get_source_from_current_image()
         self._text_padding = 30
         self.set_text("Add " + token_type.__name__)
         self.token_type = token_type
@@ -129,17 +134,15 @@ class TokenButton(ToolbarWidget):
 
     def get_event(self, event, data):
         if event == "mouse_left":
-            self.board.app.event_manager.send_event_to_containers(
+            self.board.app.event_manager.to_event_queue(
                 "Selected actor", self.token_type)
             self.parent.selected_token_type = self.token_type
             prototype = self.parent.prototypes[self.parent.selected_token_type.__name__]
             if self.parent.dummy:
                 self.parent.dummy.remove()
-            self.parent.dummy = Dummy((0,0))
-            try:
+            self.parent.dummy = Dummy((0, 0))
+            if not self.board.tokens_fixed_size:
                 self.parent.dummy.size = prototype.size
-            except miniworldmaker_exception.SizeOnTiledBoardError:
-                print("Set autosize on tiled board")
             for widget in self.parent.widgets:
                 if widget.__class__ == TokenButton:
                     widget.background_color = (180, 180, 180, 255)
